# eric7.Plugins.VcsPlugins.vcsMercurial.HisteditExtension

Package implementing the histedit extension support interface.

### Modules

HgHisteditCommitEditor | Module implementing a dialog to edit the commit message of a revision.
HgHisteditConfigDialog | Module implementing a dialog to enter the histedit parameters.
HgHisteditEditor | Module implementing the main script for histedit.
HgHisteditPlanEditor | Module implementing a dialog to edit the history modification plan.
ProjectHelper | Module implementing the histedit extension project helper.
histedit | Module implementing the histedit extension interface.